
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.apache.lucene.index.IndexReader;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.index.IndexWriterConfig;
import org.apache.lucene.queryParser.ParseException;
import org.apache.lucene.queryParser.QueryParser;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.search.Query;
import org.apache.lucene.search.ScoreDoc;

import org.apache.lucene.search.TopScoreDocCollector;
import org.apache.lucene.store.FSDirectory;
import org.apache.lucene.store.Directory;
import org.apache.lucene.store.RAMDirectory;
import org.apache.lucene.util.Version;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.File;

public class QAIndex {
	public static final String EXAMPLE_TEST = "2503461	Where do I find the dtags to change information for mp3 players?";
	
	public static Document answerParagraph(String qid, String text){
		Document doc = new Document();
		doc.add(new Field("id", qid,
            Field.Store.YES,
            Field.Index.NOT_ANALYZED));
		doc.add(new Field("text", text,
			Field.Store.YES,
            Field.Index.ANALYZED));
		return doc;
	}

	public static void readAndIndexSingleFile(String fileName, IndexWriter writer){
		BufferedReader buf = null;
		try {
			buf = new BufferedReader(new FileReader(fileName));
			String line = null;
			String[] tokens;
			String qid;
			String text;
			int count = 0;		
			while((line = buf.readLine()) != null) {
				++count;
				tokens = line.trim().split("\t");
				qid = tokens[0];
				text = tokens[1];	
				writer.addDocument(answerParagraph(qid, text));							
				if (count % 1000 == 0){
					System.err.printf("%d..", count);
				}
			}	
			System.err.printf("done!\n");
			System.err.printf("Total number of indexed documents: %d\n", count);

		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if (buf != null)
					buf.close();
			} catch (IOException ex) {
				ex.printStackTrace();
			}
		}		
	}

	public static void main(String[] args) throws IOException, ParseException {
		// directory name to store the index
        File indexDir = new File(args[0]);
        // filename with the documents to index
        String fname = args[1];

        // create an index
        Directory index = FSDirectory.open(indexDir);
        
        StandardAnalyzer analyzer = new StandardAnalyzer(Version.LUCENE_35);
        IndexWriterConfig config = new IndexWriterConfig(Version.LUCENE_35, analyzer);	    

        // insantiate an IndexWriter
        IndexWriter writer = new IndexWriter(index, config);

		
	    // read the file and write to the index
	    
	    readAndIndexSingleFile(fname, writer);	    
        writer.optimize();
        writer.close();	    
	  }	  
}